// this is based on dmap_update0304recode_2.do

* this file does recoding to create standard error and variance measures;
* of the ratio outcome;
* also creates some variables for later use;
* and corrects or adjusts counts a bit;

use dmap_update1024recoded_2_replic, clear

/* rounding now done during previous step
gen min_suc_count=round(min_succ_ct)
gen min_fail_count=round(min_fail_ct)
gen maj_suc_count=round(maj_succ_ct )
gen maj_fail_count=round(maj_fail_ct )
*/

rename min_succ_ct min_suc_count
rename min_fail_ct min_fail_count
rename maj_succ_ct maj_suc_count
rename maj_fail_ct maj_fail_count



* to not duplicate multiple effects per study
* create indicator variables of whether study has a callback outcome, an interview outcome, and/or a job offer outcome
gen tmp_call=0
replace tmp_call=1 if outcome==1
egen has_callback=max(tmp_call), by(studyid)

gen tmp_int=0
replace tmp_int=1 if outcome==2
egen has_interview=max(tmp_int), by(studyid)

gen tmp_job=0
replace tmp_job=1 if outcome==3
egen has_joboffer=max(tmp_job), by(studyid)

drop tmp_call tmp_int tmp_job

egen high_outcome=max(outcome), by(studyid)
egen low_outcome=min(outcome), by(studyid)

gen outcome2=.
replace outcome2=1 if outcome==1 & has_interview==0
replace outcome2=1 if outcome==2 & has_interview==1
replace outcome2=2 if outcome==3
label define outcome2 1 "Callback/Interview" 2 "Job Offer"
label values outcome2 outcome2

* recoding turner 1991 study
* to include application rejected stage
* pair_succ_both does not change
replace pair_majmin=47 if studyid=="Turner1991" & outcome2==1
replace pair_minmaj=14 if studyid=="Turner1991" & outcome2==1
replace pair_fail_both=184 if studyid=="Turner1991" & outcome2==1

replace minority="African-American" if minority=="African American" | minority=="black" | minority=="Black"
  
/*
Generate DV
*/
    
gen rr_unpaired=(maj_suc_count/(maj_suc_count+maj_fail_count))/(min_suc_count/(min_suc_count+min_fail_count))

* below two lines from Zhou clinical trials article
gen rr_paired=(pair_succ_both+pair_majmin)/(pair_succ_both+pair_minmaj)

gen rr_paired_lnvar= (pair_majmin+pair_minmaj)/((pair_succ_both+pair_majmin)*(pair_succ_both+pair_minmaj))

gen or_unpaired= (maj_suc_count/maj_fail_count)/(min_suc_count/min_fail_count)

* phat below is estimated intra-pair correlation coefficient
gen phat_num = (4*pair_succ_both*pair_fail_both)-(pair_majmin+pair_minmaj)^2
gen phat_denom = (2*pair_succ_both+pair_majmin+pair_minmaj)*(2*pair_fail_both+pair_majmin+pair_minmaj)
gen phat= phat_num/phat_denom

gen or_paired_marg= ((pair_succ_both+pair_majmin)/(pair_minmaj+pair_fail_both)) / ((pair_succ_both+pair_minmaj) /(pair_majmin+pair_fail_both))

gen or_paired_cond= pair_majmin/pair_minmaj
gen or_paired_cond_lnvar= 1/pair_majmin+1/pair_minmaj


* standard error formula below from:  https://www.medcalc.org/calc/relative_risk.php
* also match handbook of meta-analysis formula 19.14 (written in different form)
gen rr_unpaired_lnvar= 1/maj_suc_count+1/min_suc_count-1/(maj_suc_count+maj_fail_count)-1/(min_suc_count+min_fail_count)

gen or_unpaired_lnvar= 1/maj_suc_count+1/min_suc_count+1/maj_fail_count+1/min_fail_count

gen or_paired_marg_lnvar= (1/(pair_succ_both+pair_majmin)+1/(pair_minmaj+pair_majmin)  + 1/(pair_succ_both+pair_minmaj)+1/(pair_majmin+pair_fail_both))*(1-phat)


label define min_rec 1 "African/Black" 2 "European/White" 3 "Middle-Eastern/N. African"  4 "Latin Am./Hispanic" 5 "Asian" 6 "Other",modify
  
label values min_rec min_rec

// next section is copied from dmap_recode_2.do

* use variable below to modify some effect sizes
gen comments7=substr(comments_effects,1,7)

* for Bendick1991 and Pager2009 no effect_level=1 (overall) effect size
* due to unbalanced pairs
* but there are effect size=5
* recode to make these "overall" equivalent for these studies

replace effect_level=1 if studyid=="Bendick1991"
replace effect_level=1 if studyid=="Pager2009"

* below will be used to indicate a study having an effect size=5
egen high_effect_level=max(effect_level), by(studyid)



/*
Keep only top-level effects
Drop model-based effects
Save in separate data set
*/
 

keep if effect_level==1 | effect_level==5

* need to correct:  for Decker study need to drop
* out effect level=5 that are for gender subsamples
drop if effect_level==5 & gender~=3 & studyid=="Decker2014a"
drop if effect_level==5 & gender~=3 & studyid=="Decker2014b"

* drops model-based effects
drop if effect_type==3
*save update1213level1.dta, replace
*restore

*use update1213level1.dta, clear

sort studyid min_rec outcome
by studyid min_rec outcome:  gen effect_num=_n

tab effect_num

* below dropping interview measure based on at least one positive tester response
* we want sahres based on neither got interview only
*drop if studyid=="Bendick2010" & effect_num==2
*drop if effect_num==2 & studyid=="Turner1991"



* for rr and or measures that combine paired and unpaired 
* use paired if available, otherwise use unpaired
gen rr_best=rr_paired
replace rr_best=rr_unpaired if rr_paired==.
gen lrr_best=ln(rr_best)

gen rr_best_lnse=sqrt(rr_paired_lnvar)
replace rr_best_lnse=sqrt(rr_unpaired_lnvar) if rr_paired==.

gen or_best=or_paired_marg
replace or_best=or_unpaired if or_paired_marg==.
gen lor_best=ln(or_best)

gen or_best_lnse=sqrt(or_paired_marg_lnvar)
replace or_best_lnse=sqrt(or_unpaired_lnvar) if or_paired_marg==.

* version cond uses conditional in place of marginal ors
gen or_best_cond=or_paired_cond
replace or_best_cond=or_unpaired if or_paired_cond==.
gen lor_best_cond=ln(or_best)

gen or_best_lnse_cond=sqrt(or_paired_cond_lnvar)
replace or_best_lnse_cond=sqrt(or_unpaired_lnvar) if or_paired_cond==.


* IVs:  Now create independent variables for meta-analysis
* replace fieldwork_year missing with 1 year before publication
gen rfieldwork_year=fieldwork_year
replace rfieldwork_year=real(ustrright(studyid,4))-2 if missing(fieldwork_year) & doctype=="journal article"
replace rfieldwork_year=real(ustrright(studyid,4))-1 if missing(fieldwork_year) & doctype~="journal article"


* minority dummies
tab min_rec, gen(min)
rename min1 black
rename min2 hisp
rename min3 other

*study_method is already a dummy, with 1=audit

gen race_not_focus=0
replace race_not_focus=1 if primary_focus=="credentials" | primary_focus=="criminal record" | primary_focus=="religion"  | primary_focus=="veteran status" | primary_focus=="disability" | primary_focus=="facial appearance" | primary_focus=="for-profit college degrees" | primary_focus=="non-standard employment" | primary_focus=="professional credential"

tab primary_org, gen(org)
rename org1 academic
rename org2 advocacy
rename org3 government

gen menonly=0
replace menonly=1 if gender==1

gen femaleonly=0
replace femaleonly=1 if gender==0

gen journal_article=0
replace journal_article=1 if doctype=="journal article"

label var studyid "Study ID"
label var rfieldwork_year "Fieldwork Year"

* replace one effect size (for latinos) that is unclear if restaurant
* to be zero or restaurant
replace restaurant=0 if missing(restaurant)

save dmap_update1024recoded_3, replace

